/*
  Macro           Multi_ViewFindsBuf
  Author          Carlo Hogeveen (Was: Eliyahu Trigoub)
  Website         eCarlo.nl/tse
  Compatibility   Untested
  Version         v1.0.1   10 Apr 2024

  This extension gives every editbuffer its own ViewFinds buffer.

  Details:
    TSE's "Search" menu has a "Redisplay View PickList" function.

    Without this extension it will show the results of the last search with the
    "v" option.

    If this extension is autoloaded, then the "Redisplay View PickList"
    function will show the results of the last search with the "v" option that
    was done in the current buffer.

    A search's "a" option will be ignored if combined with the "v" option.
    This behavior was inherited from Eliyahu Trigoub's macro.
    Let me know if you want to this changed.

    This new functionality has advantages and disadvantages that depend on user
    preferences.
    The extension is simple to install and deinstall, so trying it out is easy.

  Installation and deinstallation
    To install, copy this file to TSE's "mac" directory.
    Compile it there, for example by opening it there in TSE
    and applying the Macro -> Compile menu.
    Add the macro's name to the Macro -> AutLoad List menu, and restart TSE.

    To uninstall, delete the macro's name from the Macro -> AutLoad List menu,
    and restart TSE.

  Credits:
    This extension is based on the idea and code provided by Eliyahu Trigoub:
      https://groups.google.com/g/semware/c/wC0LMqdT7KI
    I changed it into a macro that can be autoloaded, and I optimized the code.


  HISTORY

  v1        9 Apr 2024
    Initial release.

  v1.0.1   10 Apr 2024
    Documented the "a" search option being ignored if combined with the "v"
    search option.

*/



integer vfb_id


proc OnFirstEdit()
  string  EditBufferId          [10] = Str(GetBufferId())
  integer ViewFindsId_for_EditBuffer = 0

  PushLocation()
  ViewFindsId_for_EditBuffer = CreateTempBuffer()
  ChangeCurrFilename(Format(SplitPath(CurrMacroFilename(), _NAME_),
                            ':',
                            'ViewFindsBuffer_',
                            ViewFindsId_for_EditBuffer,
                            '_for_EditBuffer_',
                            EditBufferId),
                     _DONT_PROMPT_|_DONT_EXPAND_|_OVERWRITE_)
  PopLocation()

  Set(ViewFindsId, ViewFindsId_for_EditBuffer)
  SetBufferInt(EditBufferId, ViewFindsId_for_EditBuffer, vfb_id)
end OnFirstEdit


proc OnChangingFiles()
  integer ViewFindsId_for_EditBuffer = GetBufferInt(Str(GetBufferId()), vfb_id)

  if ViewFindsId_for_EditBuffer
    Set(ViewFindsId, ViewFindsId_for_EditBuffer)
  endif
end OnChangingFiles


proc OnFileQuit()
  string  EditBufferId          [10] = Str(GetBufferId())
  integer ViewFindsId_for_EditBuffer = GetBufferInt(EditBufferId, vfb_id)

  if ViewFindsId_for_EditBuffer
    AbandonFile(GetBufferInt(EditBufferId, vfb_id))
    DelBufferVar(EditBufferId, vfb_id)
  endif
end OnFileQuit


proc WhenLoaded()
  // Add a dedicated buffer for this macro's buffer variables.
  PushLocation()
  vfb_id = CreateTempBuffer()
  ChangeCurrFilename(Format(SplitPath(CurrMacroFilename(), _NAME_),
                            ':',
                            'ViewFindIdsForEditBuffers'),
                     _DONT_PROMPT_|_DONT_EXPAND_|_OVERWRITE_)
  PopLocation()

  Hook(_ON_FIRST_EDIT_    , OnFirstEdit    )
  Hook(_ON_CHANGING_FILES_, OnChangingFiles)
  Hook(_ON_FILE_QUIT_     , OnFileQuit     )
end WhenLoaded

